import mysql.connector
from pymongo import MongoClient
from .response_json import Response
from flask_api import status as http_status
import logging

logging = logging.getLogger('app.sub')


class ConnectDatabase(object):
    def __init__(self, sql_settings=None, mongo_url=None):
        """
        Info: Initialise Mysql settings
        :param sql_settings: Mysql database settings
        """
        self.mongo_url = mongo_url
        self.sql_settings = sql_settings
        self.response_obj = Response()

    def execute_procedure(self, procedure: str, params: tuple, query_type: str, return_type: bool):
        """
        Info: Execute Mysql procedure and return response.
        :param procedure: Mysql procedure name
        :param params: Params required for procedure
        :param query_type: Query type Expected values: select,delete,update,insert
        :param return_type: Boolean, If it true then procedure returns data else
        procedure not return anything
        :return: It may return array or json or boolean
        """
        try:
            # connecting to Mysql
            logging.info("connecting to mongo")
            connection = mysql.connector.connect(**self.sql_settings)
            logging.info("mysql connection established")
            cursor = connection.cursor()

            # executing mysql stored procedure
            logging.info("executing procedure {}".format(procedure))
            cursor.callproc(procedure, params)

            # Executing commit for all queries other than select
            if query_type != "select":
                connection.commit()

            # Default response is after procedure execution True
            response = True
            if return_type is True:

                # Fetching response of the procedure
                for result in cursor.stored_results():
                    response = result.fetchall()

            # closing mysql cursor
            logging.info("closing mysql connection")
            cursor.close()

            # closing mysql connection
            connection.close()
            logging.info("mysql connection closed")
            logging.info("mysql procedure {} executed".format(procedure))

            # Returning response by including data
            return self.response_obj.output_response(data=response)
        except Exception as error:
            logging.info("exception occured : {}".format(error))
            return self.response_obj.output_response(
                error=True,
                status=http_status.HTTP_500_INTERNAL_SERVER_ERROR,
                data=str(error))

    def connect_mongo_db(self, mongo_db, collection):
        """
        Info: Connecy to mongp collection
        :param collection: Mongo collection name
        :param mongo_db: Mongo database name
        :return: Mongo connection object
        """
        try:
            # Connecting to mongo collection
            logging.info("connecting to mongo")
            client = MongoClient(self.mongo_url)
            db = client[mongo_db]
            response = db[collection]
            logging.info("mongo connection established")

            # Returning response by including data
            return self.response_obj.output_response(data=response)
        except Exception as error:
            logging.info("exception occured : {}".format(error))
            return self.response_obj.output_response(
                error=True,
                status=http_status.HTTP_500_INTERNAL_SERVER_ERROR,
                data=str(error))
