import boto3
import logging
from flask_api import status as http_status
from .response_json import Response

session = boto3.Session(region_name='eu-west-1')

class SESNotification(object):
    def __init__(self,subject=None, ses_source_mail=None):
        self.ses_source_mail = ses_source_mail
        self.to_mail = []
        self.subject = subject
        self.cc_mail = []
        self.bc_mail = []
        self.html_text = ''
        self.plain_text = ''
        self.message_type = "Text"
        self.message = ""
        self.response_obj = Response()
    def to_address(self, *args):
        self.to_mail = list(args)
    def add_cc(self, *args):
        self.cc_mail = list(args)
    def add_bc(self, *args):
        self.bc_mail = list(args)
    def html(self, html_text):
        self.message_type = "Html"
        self.message = html_text
    def text(self, plain_text):
        self.message_type = "Text"
        self.message = plain_text
    def send(self):
        try:
            # Create an SNS client
            ses = session.client('ses')
            ses.send_email(
                Destination = {
                    'BccAddresses': self.bc_mail,
                    'CcAddresses': self.cc_mail,
                    'ToAddresses': self.to_mail,
                },
                Message = {
                    'Body': {
                        self.message_type: {
                            'Charset': 'UTF-8',
                            'Data': self.message,
                        },
                    },
                    'Subject': {
                        'Charset': 'UTF-8',
                        'Data': self.subject,
                    },
                },
                ReplyToAddresses=[
                ],
                Source = self.ses_source_mail
            )
        except Exception as error:
            logging.info("exception occurred while sending mail "
                         "notification : {}".format(error))
            return self.response_obj.output_response(
                error = True,
                status = http_status.HTTP_500_INTERNAL_SERVER_ERROR,
                message = "failed_to_send_ses_notification",
                data = str(error))